# Authors and Contributors

This project is developed and maintained by the Qredence team.

## Core Contributors

- Qredence - Project lead and architecture
- Zachary BENSALEM - Founder

## Acknowledgments

This project is based on academic research by:

- **Alex L. Zhang** (MIT CSAIL)
- **Omar Khattab** (Stanford)
- **Tim Kraska** (MIT)

> Reference: [Recursive Language Models](https://arxiv.org/abs/2501.123) (Zhang, Kraska, Khattab, 2025)

## Contributing

We welcome contributions! Please see [CONTRIBUTING.md](CONTRIBUTING.md) for guidelines on how to contribute to this project.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
